@@ -1,9 +1,9 @@
 import bisect
 import copy
 import json
+import re
 from functools import lru_cache
 from pathlib import Path
-import re
 
 from mutalyzer_mutator.util import reverse_complement
 from mutalyzer_retriever import retrieve_model
@@ -566,67 +566,72 @@ def yield_locations_selector_id(r_model, selector_id):
             yield feature["location"], feature["type"]
 
 
-CHR_TO_ACCESSION = {
-    "GRCh38": {
-        "1": "NC_000001.11",
-        "2": "NC_000002.12",
-        "3": "NC_000003.12",
-        "4": "NC_000004.12",
-        "5": "NC_000005.10",
-        "6": "NC_000006.12",
-        "7": "NC_000007.14",
-        "8": "NC_000008.11",
-        "9": "NC_000009.12",
-        "10": "NC_000010.11",
-        "11": "NC_000011.10",
-        "12": "NC_000012.12",
-        "13": "NC_000013.11",
-        "14": "NC_000014.9",
-        "15": "NC_000015.10",
-        "16": "NC_000016.10",
-        "17": "NC_000017.11",
-        "18": "NC_000018.10",
-        "19": "NC_000019.10",
-        "20": "NC_000020.11",
-        "21": "NC_000021.9",
-        "22": "NC_000022.11",
-        "23": "NC_000023.11",
-        "x": "NC_000023.11",
-        "X": "NC_000023.11",
-        "24": "NC_000024.10",
-        "y": "NC_000024.10",
-        "Y": "NC_000024.10",
-    },
-    "GRCh37": {
-        "1": "NC_000001.10",
-        "2": "NC_000002.11",
-        "3": "NC_000003.11",
-        "4": "NC_000004.11",
-        "5": "NC_000005.9",
-        "6": "NC_000006.11",
-        "7": "NC_000007.13",
-        "8": "NC_000008.10",
-        "9": "NC_000009.11",
-        "10": "NC_000010.10",
-        "11": "NC_000011.9",
-        "12": "NC_000012.11",
-        "13": "NC_000013.10",
-        "14": "NC_000014.8",
-        "15": "NC_000015.9",
-        "16": "NC_000016.9",
-        "17": "NC_000017.10",
-        "18": "NC_000018.9",
-        "19": "NC_000019.9",
-        "20": "NC_000020.10",
-        "21": "NC_000021.8",
-        "22": "NC_000022.10",
-        "23": "NC_000023.10",
-        "x": "NC_000023.10",
-        "X": "NC_000023.10",
-        "24": "NC_000024.9",
-        "y": "NC_000024.9",
-        "Y": "NC_000024.9",
-    },
+GRCH38 = {
+    "1": "NC_000001.11",
+    "2": "NC_000002.12",
+    "3": "NC_000003.12",
+    "4": "NC_000004.12",
+    "5": "NC_000005.10",
+    "6": "NC_000006.12",
+    "7": "NC_000007.14",
+    "8": "NC_000008.11",
+    "9": "NC_000009.12",
+    "10": "NC_000010.11",
+    "11": "NC_000011.10",
+    "12": "NC_000012.12",
+    "13": "NC_000013.11",
+    "14": "NC_000014.9",
+    "15": "NC_000015.10",
+    "16": "NC_000016.10",
+    "17": "NC_000017.11",
+    "18": "NC_000018.10",
+    "19": "NC_000019.10",
+    "20": "NC_000020.11",
+    "21": "NC_000021.9",
+    "22": "NC_000022.11",
+    "23": "NC_000023.11",
+    "X": "NC_000023.11",
+    "24": "NC_000024.10",
+    "Y": "NC_000024.10",
+}
+
+GRCH37 = {
+    "1": "NC_000001.10",
+    "2": "NC_000002.11",
+    "3": "NC_000003.11",
+    "4": "NC_000004.11",
+    "5": "NC_000005.9",
+    "6": "NC_000006.11",
+    "7": "NC_000007.13",
+    "8": "NC_000008.10",
+    "9": "NC_000009.11",
+    "10": "NC_000010.10",
+    "11": "NC_000011.9",
+    "12": "NC_000012.11",
+    "13": "NC_000013.10",
+    "14": "NC_000014.8",
+    "15": "NC_000015.9",
+    "16": "NC_000016.9",
+    "17": "NC_000017.10",
+    "18": "NC_000018.9",
+    "19": "NC_000019.9",
+    "20": "NC_000020.10",
+    "21": "NC_000021.8",
+    "22": "NC_000022.10",
+    "23": "NC_000023.10",
+    "X": "NC_000023.10",
+    "24": "NC_000024.9",
+    "Y": "NC_000024.9",
+}
+
+ASSEMBLY_ALIASES = {
+    "HG38": "GRCH38",
+    "HG19": "GRCH37",
+}
+
+ASSEMBLIES = {
+    "GRCH38": GRCH38,
+    "GRCH37": GRCH37,
 }
 
 
@@ -644,8 +649,8 @@ def get_chromosome_accession(ref_id, model):
         chromosome_number = get_model_qualifier(model, "chromosome")
         if chromosome_number is not None:
             chromosome_accessions = []
-            for assembly in CHR_TO_ACCESSION:
-                chromosome_accession = CHR_TO_ACCESSION[assembly].get(chromosome_number)
+            for assembly in ASSEMBLIES:
+                chromosome_accession = ASSEMBLIES[assembly].get(chromosome_number)
                 if chromosome_accession is not None:
                     chromosome_accessions.append((assembly, chromosome_accession))
             if chromosome_accessions:
